<?php
/**
 * Html5 Framework functions and definitions
 *
 * @package Html5 Framework
 */

require_once(get_template_directory() . '/inc/metabox/meta-functions.php');
require_once(get_template_directory() . '/dynamic-style.php');
require_once(get_template_directory() . '/customizer-options.php');
 
/*=============================================================

Woocommerce suport
	
http://docs.woothemes.com/documentation/plugins/woocommerce/codex/theming/
	
===============================================================*/

remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'my_theme_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'my_theme_wrapper_end', 10);

function my_theme_wrapper_start() {
  echo '<section id="main">';
}

function my_theme_wrapper_end() {
  echo '</section>';
}

add_theme_support( 'woocommerce' );
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

function wp_enqueue_woocommerce_style(){
    wp_register_style( 'woocommerce', get_template_directory_uri() . '/css/woocommerce.css' );
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'woocommerce' );
	}
}
add_action( 'wp_enqueue_scripts', 'wp_enqueue_woocommerce_style' );




/* Load Css in Header */

add_action( 'admin_menu', 'css_add_admin_menu' );
add_action( 'admin_init', 'css_settings_init' );


function css_add_admin_menu(  ) { 

	add_theme_page( 'Edit Css', 'Edit Css', 'manage_options', 'css', 'css_options_page' );

}


function css_settings_init(  ) { 

	register_setting( 'pluginPage', 'css_settings' );

	add_settings_section(
		'css_pluginPage_section', 
		__( 'Editeaza Css', 'html5-framework' ), 
		'css_settings_section_callback', 
		'pluginPage'
	);

	add_settings_field( 
		'css_textarea_field_0', 
		__( 'Css', 'html5-framework' ), 
		'css_textarea_field_0_render', 
		'pluginPage', 
		'css_pluginPage_section' 
	);


}


function css_textarea_field_0_render(  ) { 

	$options = get_option( 'css_settings' );
	?>
	<textarea cols='60' rows='30' name='css_settings[css_textarea_field_0]'> 
		<?php echo $options['css_textarea_field_0']; ?>
 	</textarea>
	<?php

}


function css_settings_section_callback(  ) { 

	echo __( '', 'html5-framework' );

}


function css_options_page(  ) { 

	?>
	<form action='options.php' method='post'>
		
		<h2>Edit Css</h2>
		
		<?php
		settings_fields( 'pluginPage' );
		do_settings_sections( 'pluginPage' );
		submit_button();
		?>
		
	</form>
	<?php

}



/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'html5_framework_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function html5_framework_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Html5 Framework, use a find and replace
	 * to change 'html5-framework' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'html5-framework', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 250, 190, true );
	//set_post_thumbnail_size( 720, 405, true );



	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'html5-framework' ),
	    //'social'  => __( 'Social', 'html5-framework' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'html5_framework_custom_background_args', array(
		'default-color' => '27BDF4',
		'default-image' => get_stylesheet_directory_uri() . '/images/bgsite.png',
	) ) );
}
endif; // html5_framework_setup
add_action( 'after_setup_theme', 'html5_framework_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function html5_framework_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'html5-framework' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar-left-page', 'html5-framework' ),
		'id'            => 'sidebar-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    
		register_sidebar( array(
			'name'          => __( 'First Front Widget', 'pixel_blog' ),
			'id'            => 'frontpage-banner1',
			'description'   => __( 'Appears in the banner area on the Front Page', 'pixel_blog' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		    'after_widget'  => '</aside>',
		    'before_title'  => '<h3 class="widget-title">',
		    'after_title'   => '</h3>',
		) );

	register_sidebar( array(
			'name'          => __( 'Second Front Widget', 'quark' ),
			'id'            => 'frontpage-banner2',
			'description'   => __( 'Appears in the banner area on the Front Page', 'pixel_blog' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		    'after_widget'  => '</aside>',
		    'before_title'  => '<h3 class="widget-title">',
		    'after_title'   => '</h3>',
		) );
	
	
	
	
    register_sidebar( array(
		'name'          => __( 'Footer widget [1]', 'pixel_blog' ),
		'id'            => 'footer-1',
		'description'   => 'Use this area to the left of footer',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

    register_sidebar( array(
		'name'          => __( 'Footer widget [2]', 'pixel_blog' ),
		'id'            => 'footer-2',
		'description'   => 'Use this area to the center of footer',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer widget [3]', 'pixel_blog' ),
		'id'            => 'footer-3',
		'description'   => 'Use this area to the right of footer',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'html5_framework_widgets_init' );



/**
 * Enqueue scripts and styles.
 */
function html5_framework_scripts() {
	wp_enqueue_script( 'jquery');

	wp_enqueue_style( 'html5-framework-style', get_stylesheet_uri() );
    
	wp_enqueue_style ( 'jquery.sidr.dark', get_template_directory_uri() . '/css/jquery.sidr.dark.css');
    wp_enqueue_style ( 'meniu', get_template_directory_uri() . '/css/meniu.css');

    wp_enqueue_style ( 'grid', get_template_directory_uri() . '/css/grid.css');

    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/font/font-awesome.min.css' );
	
    wp_enqueue_style( 'animate.min', get_template_directory_uri() . '/css/animate.min.css');

    wp_enqueue_style( 'font-awesome.min', get_template_directory_uri() . '/css/font-awesome.min.css');

    wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.js', array(), '20120206', true );

	wp_enqueue_script( 'fitvidspost', get_template_directory_uri() . '/js/fitvidspost.js', array(), '20120206', true );
	
	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array( 'jquery' ), '1.0.3', true );

	wp_enqueue_script( 'html5-framework-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'html5-framework-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

    wp_enqueue_script(
		'jquery.sidr.min',
		get_stylesheet_directory_uri() . '/js/jquery.sidr.min.js',
		array( 'jquery'), true);
	
	wp_enqueue_script(
		'waypoints',
		get_stylesheet_directory_uri() . '/js/waypoints.js',
		array( 'jquery'), true);

    wp_enqueue_script(
		'custom-script',
		get_stylesheet_directory_uri() . '/js/custom_script.js',
		array( 'jquery' ), true);
	


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'html5_framework_scripts' );


// Enable for widget title
add_filter('widget_title', 'do_shortcode');
// Enable for widget text
add_filter('widget_text', 'do_shortcode');


// Replaces the excerpt "more" text by a link
function new_excerpt_more($more) {
       global $post;
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');


function custom_excerpt( $length ) {
      return 25;
}
add_filter( 'excerpt_length', 'custom_excerpt', 999 );

 
function my_theme_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'after_setup_theme', 'my_theme_add_editor_styles' );


/*===========================================================
 * Register Google Fonts
 ============================================================*/

function theme_slug_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $lora = _x( 'on', 'Lora font: on or off', 'html5-framework' );
    $open_sans = _x( 'on', 'Open Sans font: on or off', 'html5-framework' );
    $yanone_kaffeesatz = _x( 'on', 'Yanone Kaffeesatz font: on or off', 'html5-framework' );
    $ubuntu = _x( 'on', 'Ubuntu font: on or off', 'html5-framework' );
    $roboto = _x( 'on', 'Roboto font: on or off', 'html5-framework' );
    $lobster = _x( 'on', 'Lobster font: on or off', 'html5-framework' );
    $poiret_one = _x( 'on', 'Poiret One font: on or off', 'html5-framework' );

    if ( 'off' !== $lora || 'off' !== $open_sans ) {
        $font_families = array();

        if ( 'off' !== $lora ) {
            $font_families[] = 'Lora:400,700,400italic';
        }

        if ( 'off' !== $open_sans ) {
            $font_families[] = 'Open Sans:700italic,400,800,600';
        }

        if ( 'off' !== $yanone_kaffeesatz ) {
            $font_families[] = 'Yanone Kaffeesatz:700italic,300,400,800,600';
        }

        if ( 'off' !== $ubuntu ) {
            $font_families[] = 'Ubuntu:700italic,400,800,600';
        }

        if ( 'off' !== $roboto ) {
            $font_families[] = 'Roboto:700italic,400,800,600';
        }

        if ( 'off' !== $lobster ) {
            $font_families[] = 'Lobster:400';
        }

        if ( 'off' !== $poiret_one ) {
            $font_families[] = 'Poiret One:400';
        }


        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );

        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }

    return $fonts_url;
}
function theme_slug_scripts_styles() {
    wp_enqueue_style( 'theme-slug-fonts', theme_slug_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'theme_slug_scripts_styles' );


/* Flush your rewrite rules */
function bt_flush_rewrite_rules() {
     flush_rewrite_rules();
}


// aq_resizer
function get_image_url() {
	$image_id = get_post_thumbnail_id();
	$image_url = wp_get_attachment_image_src($image_id,'full');
	$image_url = $image_url[0];
	echo $image_url;
	}
require_once(get_template_directory() . '/aq_resizer.php');




/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';